==> waldur_api_client-0.1.0-py3-none-any.whl: waldur_api_client/api/marketplace_plans/marketplace_plans_usage_stats_list.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.plan_usage_response import PlanUsageResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["customer_provider_uuid"] = customer_provider_uuid

    params["o"] = o

    params["offering"] = offering

    params["offering_uuid"] = offering_uuid

    params["page"] = page

    params["page_size"] = page_size

    json_parent_offering_uuid: Union[Unset, str] = UNSET
    if not isinstance(parent_offering_uuid, Unset):
        json_parent_offering_uuid = str(parent_offering_uuid)
    params["parent_offering_uuid"] = json_parent_offering_uuid

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/marketplace-plans/usage_stats/",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[list["PlanUsageResponse"]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = PlanUsageResponse.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["PlanUsageResponse"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Response[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlanUsageResponse']]
    """

    kwargs = _get_kwargs(
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Optional[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlanUsageResponse']
    """

    return sync_detailed(
        client=client,
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Response[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlanUsageResponse']]
    """

    kwargs = _get_kwargs(
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Optional[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlanUsageResponse']
    """

    return (
        await asyncio_detailed(
            client=client,
            customer_provider_uuid=customer_provider_uuid,
            o=o,
            offering=offering,
            offering_uuid=offering_uuid,
            page=page,
            page_size=page_size,
            parent_offering_uuid=parent_offering_uuid,
        )
    ).parsed

==> waldur_api_client-7.7.0-py3-none-any.whl: waldur_api_client/api/marketplace_plans/marketplace_plans_usage_stats_list.py <==
from http import HTTPStatus
from typing import Any, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.plan_usage_response import PlanUsageResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["customer_provider_uuid"] = customer_provider_uuid

    params["o"] = o

    params["offering"] = offering

    params["offering_uuid"] = offering_uuid

    params["page"] = page

    params["page_size"] = page_size

    json_parent_offering_uuid: Union[Unset, str] = UNSET
    if not isinstance(parent_offering_uuid, Unset):
        json_parent_offering_uuid = str(parent_offering_uuid)
    params["parent_offering_uuid"] = json_parent_offering_uuid

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/marketplace-plans/usage_stats/",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> list["PlanUsageResponse"]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = PlanUsageResponse.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["PlanUsageResponse"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Response[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlanUsageResponse']]
    """

    kwargs = _get_kwargs(
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> list["PlanUsageResponse"]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlanUsageResponse']
    """

    return sync_detailed(
        client=client,
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> Response[list["PlanUsageResponse"]]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['PlanUsageResponse']]
    """

    kwargs = _get_kwargs(
        customer_provider_uuid=customer_provider_uuid,
        o=o,
        offering=offering,
        offering_uuid=offering_uuid,
        page=page,
        page_size=page_size,
        parent_offering_uuid=parent_offering_uuid,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    customer_provider_uuid: Union[Unset, str] = UNSET,
    o: Union[Unset, str] = UNSET,
    offering: Union[Unset, str] = UNSET,
    offering_uuid: Union[Unset, str] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    parent_offering_uuid: Union[Unset, UUID] = UNSET,
) -> list["PlanUsageResponse"]:
    """
    Args:
        customer_provider_uuid (Union[Unset, str]):
        o (Union[Unset, str]):
        offering (Union[Unset, str]):
        offering_uuid (Union[Unset, str]):
        page (Union[Unset, int]):
        page_size (Union[Unset, int]):
        parent_offering_uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['PlanUsageResponse']
    """

    return (
        await asyncio_detailed(
            client=client,
            customer_provider_uuid=customer_provider_uuid,
            o=o,
            offering=offering,
            offering_uuid=offering_uuid,
            page=page,
            page_size=page_size,
            parent_offering_uuid=parent_offering_uuid,
        )
    ).parsed
